/*******************************************************************************
**	NONE ramdac driver
********************************************************************************
**
   Copyright (C) 1999 Andreas Beck
**
   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
**
********************************************************************************
*/

#include <kgi/maintainers.h>
#define	MAINTAINER	Andreas_Beck
#define	DRIVER_NAME	"dummy DAC driver"
#define	DRIVER_REV	"$Revision: 1.10 $"

#include <kgi/kgi.h>
#include <kgi/module.h>

static struct kgi_ramdac ramdac = {

	"NONE",				/* manufacturer		*/
 	"NONE",				/* model		*/
	GM_ALL,				/* supported modes	*/
 	0,			 	/* flags		*/
 	{ 0xFFFF, 0xFFFF },		/* maximum resolution	*/
	NULL,				/* Private data hook	*/
	0,				/* device type		*/
	  {       0,  32000000 },	/* normal mode		*/
	  {       0,  32000000 },	/* 2xclk mode		*/

	 {{	  0,  32000000 },	/* 	KGIGT_TEXT16	*/
	  {	  0,  32000000 },	/* 	KGIGT_TEXT32 	*/
	  {       0,  32000000 },	/* 	KGIGT_1BIT		*/
	  {	  0,  32000000 },	/* 	KGIGT_4BIT		*/
	  {       0,  32000000 },	/* 	KGIGT_8BIT		*/	
	  {	  0,  32000000 },	/* 	KGIGT_15BIT	*/
	  { 	  0,  32000000 },	/* 	KGIGT_16BIT	*/
	  {       0,  32000000 },	/* 	KGIGT_24BIT	*/
	  {	  0,  32000000 }}	/* 	KGIGT_32BIT	*/
};

/*
**	GGI interface
*/

int kgim_ramdac_init(struct kgi_card *card,struct kgi_display *dpy)
{
        NOTICE(DRIVER_NAME " rev " DRIVER_REV);
        card->ramdac = &ramdac;
        return EOK;
}

void kgim_ramdac_done(struct kgi_display *dpy)
{
       NOTICE(DRIVER_NAME " removed.");
}

int kgim_ramdac_check_mode (struct kgi_display *dpy, struct kgi_mode *mode,
	enum kgi_tm_cmd *cmd)
{
        switch (*cmd) {

        case CMD_PROPOSE:
                mode->lclk.mul = mode->clk.mul = 1;
                mode->lclk.div = mode->clk.div = 1;
                return EOK;
                
        case CMD_LOWER:
        case CMD_RAISE:
                return EOK;

        case CMD_CHECK:
                if ((mode->lclk.mul != 1) || (mode->lclk.div != 1) ||
                    (mode->clk.mul  != 1) || (mode->clk.div  != 1)) {

                        return -E(RAMDAC,MODE_CHECK);
		}
                
                return EOK;
                
        default:
                INTERNAL_ERROR;
                return -E(RAMDAC,BOGUS);
        }
}

void kgim_ramdac_set_mode(struct kgi_display *display,struct kgi_mode *mode)
{
}

int kgim_ramdac_command(struct kgi_graphic *graph, kgi_uint cmd, kgi_uint arg)
{
        /* This driver can't do this. */
        return -E(RAMDAC,NOSUP_ALWAYS_CANT);
}

